
# Slot: neurodata_types


an optional list of strings indicating which data types should be included from the given specification source or namespace. The default is null indicating that all data types should be included.

URI: [nwb_schema_language:neurodata_types](https://w3id.org/p2p_ld/nwb-schema-language/neurodata_types)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Schema](Schema.md)
